$: << "./test/"
Dir['{spec,test}/**/*.rb'].each { |f| require f }
